import argparse
from datetime import datetime, timedelta
import json
from progress.bar import IncrementalBar

from vcinema_utils import VCinemaUtils


def get_new_countries(token_id, token_secret, start_date, end_date):
    print("Getting viewings")
    viewings = VCinemaUtils.get_vcinema_viewings(token_id, token_secret)

    with IncrementalBar('Retrieving movie data', max=len(viewings), suffix='%(percent).1f%% - %(eta)ds remaining', check_tty=False) as bar:
        VCinemaUtils.add_imdb_data_to_viewings(viewings, ["countries"], bar)

    pre_range_viewings = VCinemaUtils.get_viewings_in_date_range(viewings, datetime.min, start_date - timedelta(days=1))
    in_range_viewings = VCinemaUtils.get_viewings_in_date_range(viewings, start_date, end_date)

    pre_range_countries = set(list(VCinemaUtils.filter_viewings(pre_range_viewings, "countries").keys()))
    in_range_countries = set(list(VCinemaUtils.filter_viewings(in_range_viewings, "countries").keys()))

    new_countries = in_range_countries - pre_range_countries

    print(f"New countries in range {start_date.strftime('%d-%m-%Y')} - {end_date.strftime('%d-%m-%Y')}:")
    print("\n".join(new_countries))


if __name__ == '__main__':
    parser = argparse.ArgumentParser()

    parser.add_argument('start_date', type=lambda s: datetime.strptime(s, '%d-%m-%Y'))
    parser.add_argument('end_date', type=lambda s: datetime.strptime(s, '%d-%m-%Y'))

    args = parser.parse_args()

    with open('../token.json') as json_file:
        token = json.load(json_file)

    get_new_countries(token['token_id'], token['token_secret'], args.start_date, args.end_date)
